/*
  Simple countdown timer shown as time (counting down) which will start when a button is pressed.

  Author: F. van Slooten
*/
#include <U8g2lib.h>

#define START_BTN 4

U8X8_SSD1306_128X64_NONAME_HW_I2C display(U8X8_PIN_NONE);

int count = 100; // start value of the counter (in seconds)

char buf[10]; // text buffer; to be able to use draw2x2String to show the value

void setup() {
  Serial.begin(9600);
  pinMode(START_BTN, INPUT_PULLUP); // start button, without resistor (internal pull-up)
  display.begin();
  display.setPowerSave(0);
  display.setFont(u8x8_font_pxplusibmcgathin_f);

  // wait until button pressed to proceed:
  // (this while statement halts the program, until the button is pressed)
  while(digitalRead(START_BTN)==HIGH) ; // note the empty statement: ';' does nothing, thus waits for START_BTN to be pressed (becomes LOW)
  display.drawString(0, 7, "running");
  Serial.println("Countdown running");
}

void loop() {
  if (count>=0) { // if counter not finished
    int min = count/60;
    int sec = count%60;
    sprintf(buf, "%02d:%02d", min, sec);
    display.draw2x2String(2,3,buf);
    count = count - 1; // decrease counter
  }
  else {
    Serial.println("Countdown finished");
    display.drawString(0, 7, "finished");
  }
  delay(1000); // wait one second
}
